====================================
Using the Abaqus Scripting Interface
====================================

This section provides an introduction to the Python programming language and a discussion of how you can combine Python statements and the Abaqus Scripting Interface to create your own scripts.

.. toctree::
   :maxdepth: 1
   :caption: Contents

   python/introduction
   python/python-abaqus
   python/use-scripts